# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.2] - 2025-08-08

### Added
- Async support
- Added user value to model creation log

## [0.1.1] - 2025-07-24

### Added
- User field added to list filter in admin dashboard

## [0.1.0] - 2025-07-20

### Added
- Initial release
- Database logging with Django admin
- HTTP middleware integration  
- Django signals monitoring
- Sensitive data masking
- Management commands
- Comprehensive documentation